.. pop documentation master file, created by
   sphinx-quickstart on Mon Jun 25 20:19:13 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

Welcome to pop's documentation!
===============================

.. toctree::
   :maxdepth: 2
   :glob:

   tutorial/quickstart
   topics/learning
   topics/hub_overview
   topics/subs_overview
   topics/sub_patterns
   topics/conf
   topics/conf_integrate
   topics/app_merging
   topics/dyne_name
   topics/contracts
   topics/func_alias
   topics/story
   topics/pop
   topics/glossary
   topics/ideas_that_were_not_used
   releases/*


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
